/******************************************************************************
 * Copyright (C) 2008 Amine Bouchikhi <bouchikhi.amine@gmail.com>             *
 *                                                                            *
 * This program is free software; you can redistribute it and/or              *
 * modify it under the terms of the GNU General Public License as             *
 * published by the Free Software Foundation; either version 2 of             *
 * the License, or (at your option) any later version.                        *
 *                                                                            *
 * This program is distributed in the hope that it will be useful,            *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of             *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the              *
 * GNU General Public License for more details.                               *
 *                                                                            *
 * You should have received a copy of the GNU General Public License          *
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.      *
 ******************************************************************************/

#ifndef ROOT_DBUS_HANDLER_H
#define ROOT_DBUS_HANDLER_H

#include <QObject>
#include <QDBusArgument>

#include "../kscd.h"

struct Version
{
    quint16 major;
    quint16 minor;
};


// Marshall the DBusVersion data into a D-BUS argument
QDBusArgument &operator<<(QDBusArgument &argument, const Version &version);
// Retrieve the DBusVersion data from the D-BUS argument
const QDBusArgument &operator>>(const QDBusArgument &argument, Version &version);

namespace KsCD
{
    class RootDBusHandler : public QObject
    {
        Q_OBJECT

    private: 
    	KSCD * player;
        
        public:
            RootDBusHandler(KSCD * kscd);
            QString Identity();
            void Quit();
            Version MprisVersion();
    };
}

#endif
